@@ -105,6 +105,12 @@ typedef struct {
 
 static mazestruct mazes[MAXSCREENS];
 
+static int choose_door();
+static int backup();
+static void draw_wall();
+static void draw_solid_square();
+static void enter_square();
+
 void
 initmaze(win)
     Window win;
@@ -130,44 +136,8 @@ initmaze(win)
     mp->counter = 0;
 }
 
-void
-drawmaze(win)
-    Window win;
-{
-    mazestruct *mp = &mazes[screen];
-    switch (mp->counter)
-    {
-      case 0:
-	clear_window(win);
-	set_maze_sizes();
-      	initialize_maze();
-        break;
-      case 1:
-      	draw_maze_border(win);
-        break;
-      case 2:
-	create_maze(win);
-        break;
-      case 3:
-      case 4:
-	(void) sleep(1);
-        break;
-      case 5:
-	solve_maze(win);
-        break;
-      case 6:
-      case 7:
-      case 8:
-      case 9:
-      	(void) sleep(1);
-        break;
-    }
-    if (mp->counter == 9)
-      mp->counter = 0;
-    else
-      mp->counter++;
-} /*  end of drawmaze() */
 
+static void
 clear_window(win) /* blank the window */
         Window win;
 {
@@ -178,6 +148,7 @@ clear_window(win) /* blank the window */
 } /* end of clear_window() */
 
 
+static void
 set_maze_sizes()
 {
         mazestruct *mp = &mazes[screen];
@@ -210,6 +181,7 @@ set_maze_sizes()
 } /* end of set_maze_sizes */
 
 
+static void
 initialize_maze() /* draw the surrounding wall and start/end squares */
 {
         mazestruct *mp = &mazes[screen];
@@ -323,6 +295,7 @@ initialize_maze() /* draw the surrounding wall and start/end squares */
 }
 
 
+static void
 create_maze(win) /* create a maze layout given the intiialized maze */
         Window win;
 {
@@ -371,6 +344,7 @@ create_maze(win) /* create a maze layout given the intiialized maze */
 } /* end of create_maze() */
 
 
+static int
 choose_door(win) /* pick a new path */
         Window win;
 {
@@ -438,6 +412,7 @@ choose_door(win) /* pick a new path */
 } /* end of choose_door() */
 
 
+static int
 backup() /* back up a move */
 {
         mazestruct *mp = &mazes[screen];
@@ -448,6 +423,7 @@ backup() /* back up a move */
 } /* end of backup() */
 
 
+static void
 draw_maze_border(win) /* draw the maze outline */
         Window win;
 {
@@ -506,6 +482,7 @@ draw_maze_border(win) /* draw the maze outline */
 } /* end of draw_maze() */
 
 
+static void
 draw_wall(win, i, j, dir) /* draw a single wall */
         Window win;
 	int i, j, dir;
@@ -544,6 +521,7 @@ draw_wall(win, i, j, dir) /* draw a single wall */
 } /* end of draw_wall */
 
 
+static void
 draw_solid_square(win, i, j, dir, gc) /* draw a solid square in a square */
         Window win;
 	register int i, j, dir;
@@ -575,6 +553,8 @@ draw_solid_square(win, i, j, dir, gc) /* draw a solid square in a square */
 
 } /* end of draw_solid_square() */
 
+
+static void
 solve_maze(win) /* solve it with graphical feedback */
         Window win;
 {
@@ -614,6 +594,7 @@ solve_maze(win) /* solve it with graphical feedback */
 } /* end of solve_maze() */
 
 
+static void
 enter_square(win, n) /* move into a neighboring square */
         Window win;
 	int n;
@@ -640,3 +621,42 @@ enter_square(win, n) /* move into a neighboring square */
 
 
 } /* end of enter_square() */
+
+void
+drawmaze(win)
+    Window win;
+{
+    mazestruct *mp = &mazes[screen];
+    switch (mp->counter)
+    {
+      case 0:
+	clear_window(win);
+	set_maze_sizes();
+      	initialize_maze();
+        break;
+      case 1:
+      	draw_maze_border(win);
+        break;
+      case 2:
+	create_maze(win);
+        break;
+      case 3:
+      case 4:
+	(void) sleep(1);
+        break;
+      case 5:
+	solve_maze(win);
+        break;
+      case 6:
+      case 7:
+      case 8:
+      case 9:
+      	(void) sleep(1);
+        break;
+    }
+    if (mp->counter == 9)
+      mp->counter = 0;
+    else
+      mp->counter++;
+} /*  end of drawmaze() */
+
