@@ -11,6 +11,7 @@ static char sccsid[] = "@(#)resource.c	1.20 91/09/27 XLOCK";
  * Revision History:
  *
  * Changes of David Bagley (bagleyd@source.asset.com)
+ * 20-Sep-94: added bat mode from Lorenzo Patocchi <patol@info.isbiel.ch>
  * 11-Jul-94: added grav mode, and inwindow option from Greg Bowering
  *            <greg@cs.adelaide.edu.au>
  * 22-Jun-94: Modified for VMS
@@ -38,14 +39,10 @@ static char sccsid[] = "@(#)resource.c	1.20 91/09/27 XLOCK";
  */
 
 #include <stdio.h>
-#ifdef VMS
-#include <stdlib.h>
-#endif
 #include "xlock.h"
 #include <netdb.h>
 #include <math.h>
 #include <ctype.h>
-
 #include <X11/Xresource.h>
 
 /*
@@ -112,6 +109,15 @@ extern void drawworld();
 extern void initrect();
 extern void drawrect();
 
+extern void initbat();
+extern void drawbat();
+
+extern void initgalaxy();
+extern void drawgalaxy();
+
+extern void initkaleid();
+extern void drawkaleid();
+
 typedef struct {
     char       *cmdline_arg;
     void        (*lp_init) ();
@@ -144,9 +150,13 @@ static LockStruct LockProcs[] = {
     {"bounce", initbounce, drawbounce, 10000, 10, 1.0, "Bouncing ball"},
     {"world", initworld, drawworld, 100000, 8, 0.3, "Random Spinning Earths"},
     {"rect", initrect, drawrect, 10000, 100, 1.0, "Greynetic rectangles"},
+    {"bat", initbat, drawbat, 10000, 6, 1.0, "Flying Bats"},
+    {"galaxy", initgalaxy, drawgalaxy, 100, 3, 1.0, "Spinning galaxies"},
+    {"kaleid", initkaleid, drawkaleid, 2000, 4, 1.0, "Kaleidoscope"},
     {"blank", initblank, drawblank, 5000000, 1, 1.0, "Blank screen"},
     {randomstring, NULL, NULL, 0, 0, 0.0, "Random mode"},
 };
+
 #define NUMPROCS (sizeof LockProcs / sizeof LockProcs[0])
 
 #ifndef MAXHOSTNAMELEN
@@ -213,6 +223,8 @@ static XrmOptionDescRec genTable[] = {
     {"+v", ".verbose", XrmoptionNoArg, (caddr_t) "off"},
     {"-inwindow",".inwindow", XrmoptionNoArg, (caddr_t) "on"},
     {"+inwindow",".inwindow", XrmoptionNoArg, (caddr_t) "off"},
+    {"-timeelapsed", ".timeelapsed", XrmoptionNoArg, (caddr_t) "on"},
+    {"+timeelapsed", ".timeelapsed", XrmoptionNoArg, (caddr_t) "off"},
     {"-nice", ".nice", XrmoptionSepArg, (caddr_t) NULL},
     {"-timeout", ".timeout", XrmoptionSepArg, (caddr_t) NULL},
     {"-font", ".font", XrmoptionSepArg, (caddr_t) NULL},
@@ -269,6 +281,7 @@ static OptionStruct opDesc[] = {
     {"-/+usefirst", "turn on/off using the first char typed in password"},
     {"-/+v", "turn on/off verbose mode"},
     {"-/+inwindow", "turn on/off making xlock run in a window"},
+    {"-/+timeelapsed", "turn on/off clock"},
     {"-delay usecs", "microsecond delay between screen updates"},
     {"-batchcount num", "number of things per batch"},
     {"-nice level", "nice level for xlock process"},
@@ -310,6 +323,7 @@ Bool        echokeys;
 Bool        usefirst;
 Bool        verbose;
 Bool        inwindow;
+Bool        timeelapsed;
 
 #define t_String	0
 #define t_Float		1
@@ -345,6 +359,7 @@ static argtype genvars[] = {
     {(caddr_t *) &usefirst, "usefirst", "Usefirst", "off", t_Bool},
     {(caddr_t *) &verbose, "verbose", "Verbose", "off", t_Bool},
     {(caddr_t *) &inwindow, "inwindow", "InWindow", "off", t_Bool},
+    {(caddr_t *) &timeelapsed, "timeelapsed", "TimeElapsed", "off", t_Bool},
 };
 #define NGENARGS (sizeof genvars / sizeof genvars[0])
 
@@ -826,7 +841,7 @@ GetResources(argc, argv)
 }
 
 
-CheckResources()
+void CheckResources()
 {
     int         i;
 
