@@ -139,9 +139,8 @@ static char sccsid[] = "@(#)xlock.c	23.21 91/06/27 XLOCK";
 #ifndef VMS
 #include <pwd.h>
 #endif
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__NetBSD__)
 #include <sys/types.h>
-#include <stdlib.h>
 #endif
 
 #include "xlock.h"
@@ -150,6 +149,7 @@ static char sccsid[] = "@(#)xlock.c	23.21 91/06/27 XLOCK";
 
 extern char *crypt();
 extern char *getenv();
+extern void CheckResources();
 
 char       *ProgramName;	/* argv[0] */
 perscreen   Scr[MAXSCREENS];
@@ -157,6 +157,7 @@ Display    *dsp = NULL;		/* server display connection */
 int         screen;		/* current screen */
 void        (*callback) () = NULL;
 void        (*init) () = NULL;
+long	start_time;
 
 static int  screens;		/* number of screens */
 static Window win[MAXSCREENS];	/* window used to cover screen */
@@ -515,9 +516,23 @@ getPassword()
     rootuser.addr  = root;
  
     sys$getuai(0,0,&rootuser,&il,0,0,0);
+#else
+#ifdef OSF1_ENH_SEC
+  struct pr_passwd *pw;
+
+  pw = getprpwnam("root");
+  strcpy(rootpass, pw->ufld.fd_encrypt);
+
+  pw = getprpwuid (getuid());
+  strcpy(userpass, pw->ufld.fd_encrypt);
+  user = pw->ufld.fd_name;
+
 #else
     struct passwd *pw;
 
+#ifdef __NetBSD__
+    seteuid(0);                       /* Need to be root now on NetBSD */
+#endif
     pw = (struct passwd *)getpwnam("root");
     (void) strcpy(rootpass, pw->pw_passwd);
 
@@ -525,10 +540,24 @@ getPassword()
     pw = (struct passwd *)getpwnam(cuserid(NULL));
 #else
     pw = (struct passwd *)getpwuid(getuid());
+#endif
+#if defined(HAS_SHADOW) && defined(linux)
+   {
+     struct spwd *spw;
+
+     if ((spw = getspnam(pw->pw_name)) == NULL)
+       pw->pw_passwd = "";
+     else
+       pw->pw_passwd = spw->sp_pwdp;
+    }
 #endif
     (void) strcpy(userpass, pw->pw_passwd);
 
     user = pw->pw_name;
+#endif
+#ifdef __NetBSD__
+    seteuid(getuid());                /* Don't need to be root anymore */
+#endif
 #endif
 
     XGetWindowAttributes(dsp, win[screen], &xgwa);
@@ -567,6 +596,21 @@ getPassword()
     XDrawString(dsp, win[screen], textgc[screen],
 		iconx[screen], y, text_info, strlen(text_info));
 
+    if (timeelapsed) {
+      char clock[16];
+      int day, hr, min, sec;
+      long time_displayed = seconds() - start_time;
+      if (time_displayed < 0)
+        time_displayed = 0;
+      day = (int) (time_displayed / (24 * 60 * 60));
+      hr = (int) ((time_displayed / (24 * 60)) % 60);
+      min = (int) ((time_displayed / 60) % 60);
+      sec = (int) (time_displayed % 60);
+      (void) sprintf (clock, "%d:%02d:%02d:%02d", day, hr, min, sec);
+      y += font->ascent + font->descent + 2;
+      XDrawString(dsp, win[screen], textgc[screen],
+		iconx[screen], y, clock, strlen(clock));
+    }
     XFlush(dsp);
 
     y += font->ascent + font->descent + 2;
@@ -600,8 +644,13 @@ getPassword()
         done = !((strcmp(hash_password,hash_system)) &&
                  (!allowroot || strcmp(root_password,root_system)));
 #else
-	done = !((strcmp(crypt(buffer, userpass), userpass))
-	       && (!allowroot || strcmp(crypt(buffer, rootpass), rootpass)));
+#if defined(HAS_SHADOW) && defined(linux)
+        done = !((strcmp(pw_encrypt(buffer, userpass), userpass)) &&
+          (!allowroot || strcmp(pw_encrypt(buffer, rootpass), rootpass)));
+#else
+	done = !((strcmp(crypt(buffer, userpass), userpass)) &&
+          (!allowroot || strcmp(crypt(buffer, rootpass), rootpass)));
+#endif
 #endif
 	if (!done && !*buffer) {
 	    /* just hit return, and it wasn't his password */
@@ -769,7 +818,16 @@ main(argc, argv)
     else
 	ProgramName = argv[0];
 
-    srandom(time((long *) 0));	/* random mode needs the seed set. */
+#ifdef OSF1_ENH_SEC
+    set_auth_parameters();
+#endif
+
+#ifdef __NetBSD__
+    seteuid(getuid());
+#endif
+
+    start_time = time((long *) 0);
+    srandom(start_time);	/* random mode needs the seed set. */
 
     GetResources(argc, argv);
 
